"""
Configuration constants for x.com automation, including:
- labels: UI label strings used for element matching in different locales.
- endpoints: Common URL paths for login, home, new post, etc.
- locators: CSS or attribute-based selectors for identifying DOM elements
  on x.com pages.
"""

labels = {
    "en-US": {
        "cookies_accept_all": "Accept all cookies",
        "cookies_accept_essential": "Refuse non-essential cookies",
        "notifications_allow": "Allow notifications",
        "notifications_skip": "Skip for now",
        "post_input": "What is happening?!",
        "add_post_button": "Post",
        "login_input": "Phone, email, or username",
        "login_next_button": "Next",
        "login_phone_or_user_name_input": "Phone or username",
        "login_password_input": "Password",
        "login_login_button": "Log in",
        "follow": "Follow",
        "unfollow": "Unfollow",
        "following": "Following",
        "show_replies": "Show replies",
    },
}

endpoints = {
    "login": "/i/flow/login",
    "home": "/home",
    "root": "/",
    "new_post": "/compose/post",
}

locators = {
    "account_menu_button": "button[aria-label='Account menu']",
    "post_input_editor_div": "div[aria-labelledby='modal-header'] div.notranslate.public-DraftEditor-content",
    "post_editor_submit_button": "div[aria-labelledby='modal-header'] button[data-testid='postButton']",
    "page_root": "div#react-root",
    "post_overlay": "div[data-testid='mask']",
    "posts_list_div": "div[aria-label='Timeline: Your Home Timeline']",
    "close_notifications_popup": "aria-label=Close",
    "home_timeline_tabs": 'div[data-testid="ScrollSnap-SwipeableList"]  > div[role="tablist"] div a',
    "more_posts_button": "div[data-testid='cellInnerDiv'] button",
    "post": "article[data-testid='tweet']",
    "post_content_show_more": 'div > div > div > div > div > div[data-testid="tweet-text-show-more-link"]',
    "post_user_name_div": "div[data-testId='User-Name']",
    "post_simple_repost": 'span[data-testid="socialContext"]',
    "post_text_div": "div[data-testid='tweetText']",
    "post_attachments": "div[aria-labelledby]",
    "post_poll_attachment": 'div[data-testid="cardPoll"]',
    "post_poll_attachment_option": 'div[role="radio"]',
    "post_poll_attachment_info": 'div[dir] > div > span',
    "post_video_attachment": "div[data-testid='videoComponent']",
    "post_post_attachment": 'div[tabindex][role="link"] div',
    "post_post_attachment_user_div": 'div[data-testid="User-Name"]',
    "post_post_attachment_user_name": 'span span',
    "post_post_attachment_user_handle": 'div[tabindex] span',
    "post_post_attachment_text_div": 'div[data-testid="tweetText"]',
    "post_stat": 'div[role="group"] > div ',
    "post_page_buttons": "article[data-testId='tweet'] div[aria-label][id]",
    "post_page_reply_input": "div[data-testid='tweetTextarea_0']",
    "post_page_reply_button": "button[data-testid='tweetButtonInline']",
    "post_page_retweet_buttons": "button[data-testid='repost']",
    "post_page_unrepost_buttons": "button[data-testid='unretweet']",
    "post_page_repost_mode_quote": " div[data-testid='Dropdown'] > a[role='menuitem']",
    "post_page_repost_mode_simple": " div[data-testid='Dropdown'] > div[data-testid='retweetConfirm']",
    "post_page_unrepost_mode_simple": " div[data-testid='Dropdown'] > div[data-testid='unretweetConfirm']",
    "post_repost_quote_input": " div[aria-labelledby='modal-header'] div[data-testid='tweetTextarea_0']",
    "post_repost_quote_button": "div[aria-labelledby='modal-header'] button[data-testid='tweetButton']",
    "post_page_like_button": "button[data-testid='like']",
    "post_page_unlike_button": "button[data-testid='unlike']",
    "post_page_bookmark_button": "button[data-testid='bookmark']",
    "post_page_unbookmark_button": "button[data-testid='removeBookmark']",
    "post_page_posted_datetime": "time[datetime]",
    "post_input_hashtag_popup_div": "div#typeaheadDropdownWrapped-1",
    "post_page_content_container": 'div[data-testid="cellInnerDiv"]',
    "post_page_comments_and_post": 'article',
    "post_page_comment_ad": 'div > div  > div[data-testid="placementTracking"]',
    "post_page_separator": 'div:empty:first-of-type',
    "post_discover_more_header": 'div h2',
    "post_page_show_more_replies_button": 'div div div button div div div span',
    "profile_page_menu_button": 'a[data-testid="AppTabBar_Profile_Link"]',
    "profile_page_user_div": 'div[data-testid="UserName"] > div > div> div > div',
    "profile_headline_items": 'div[data-testid="UserProfileHeader_Items"]',
    "profile_headline_item_user_join_date": 'span[data-testid="UserJoinDate"]',
    "profile_headline_item_user_location": 'span[data-testid="UserLocation"]',
    "profile_headline_item_user_url": 'a[data-testid="UserUrl"]',
    "profile_headline_item_user_birthday": 'a[data-testid="UserBirthdate"]',
    "profile_headline_item_user_bio": 'div[data-testid="UserDescription"]',
    "profile_headline_follows": 'div > div > div > div > div > div > div > div > div > div > a[role="link"][dir]',
    "profile_follow_unfollow_button": 'div[data-testid="placementTracking"] > div > button',
    "profile_unfollow_popup_confirm_button": 'button[type="button"][role="button"][data-testid="confirmationSheetConfirm"]',
}
